@@ -1,5 +1,6 @@
 #!perl -w
 use strict;
+use Log::Log4perl qw(:easy);
 use WWW::Mechanize::Chrome;
 
 my $mech = WWW::Mechanize::Chrome->new();
@@ -16,11 +17,11 @@ sendkeys.pl - send keystrokes to a page
 
 =head1 SYNOPSIS
 
-    sendkeys.pl
+    perl sendkeys.pl
 
 =head1 DESCRIPTION
 
 B<This program> demonstrates how to type some input into a text field
 and then press the C<enter> key.
 
-=cut
\ No newline at end of file
+=cut
